@@ -760,6 +760,7 @@ static ssize_t PrintChannelStatistics(FILE *file,const ChannelType channel,
       ClampToQuantum(scale*(QuantumRange-channel_statistics[channel].maxima)),
       GetMagickPrecision(),scale*(QuantumRange-
       channel_statistics[channel].mean),GetMagickPrecision(),scale*
+      IsNaN(channel_statistics[channel].standard_deviation) != 0 ? MagickEpsilon :
       channel_statistics[channel].standard_deviation,GetMagickPrecision(),
       channel_statistics[channel].kurtosis,GetMagickPrecision(),
       channel_statistics[channel].skewness,GetMagickPrecision(),
@@ -770,6 +771,7 @@ static ssize_t PrintChannelStatistics(FILE *file,const ChannelType channel,
       GetMagickPrecision(),(double) ClampToQuantum(scale*
       channel_statistics[channel].maxima),GetMagickPrecision(),scale*
       channel_statistics[channel].mean,GetMagickPrecision(),scale*
+      IsNaN(channel_statistics[channel].standard_deviation) != 0 ? MagickEpsilon :
       channel_statistics[channel].standard_deviation,GetMagickPrecision(),
       channel_statistics[channel].kurtosis,GetMagickPrecision(),
       channel_statistics[channel].skewness,GetMagickPrecision(),
@@ -1739,6 +1741,9 @@ static MagickBooleanType WriteJSONImage(const ImageInfo *image_info,
   MagickOffsetType
     scene;
 
+  size_t
+    imageListLength;
+
   /*
     Open output image file.
   */
@@ -1752,6 +1757,7 @@ static MagickBooleanType WriteJSONImage(const ImageInfo *image_info,
   if (status == MagickFalse)
     return(status);
   scene=0;
+  imageListLength=GetImageListLength(image);
   do
   {
     if (scene == 0)
@@ -1768,8 +1774,7 @@ static MagickBooleanType WriteJSONImage(const ImageInfo *image_info,
       }
     (void) WriteBlobString(image,",\n");
     image=SyncNextImageInList(image);
-    status=SetImageProgress(image,SaveImagesTag,scene++,
-      GetImageListLength(image));
+    status=SetImageProgress(image,SaveImagesTag,scene++,imageListLength);
     if (status == MagickFalse)
       break;
   } while (image_info->adjoin != MagickFalse);
