@@ -27,12 +27,12 @@ extern "C" {
 */
 #define MagickPackageName "ImageMagick"
 #define MagickCopyright  "© 1999-2018 ImageMagick Studio LLC"
-#define MagickLibVersion  0x699
-#define MagickLibVersionText  "6.9.9"
-#define MagickLibVersionNumber  5,0,0
-#define MagickLibAddendum  "-34"
-#define MagickLibInterface  5
-#define MagickLibMinInterface  5
+#define MagickLibVersion  0x69A
+#define MagickLibVersionText  "6.9.10"
+#define MagickLibVersionNumber  6,0,0
+#define MagickLibAddendum  "-2"
+#define MagickLibInterface  6
+#define MagickLibMinInterface  6
 #if defined(_WINDOWS)
 #  if defined(_WIN64)
 #    define MagickPlatform "x64"
@@ -42,16 +42,16 @@ extern "C" {
 #else
 #define MagickPlatform  "x86_64"
 #endif
-#define MagickppLibVersionText  "6.9.9"
+#define MagickppLibVersionText  "6.9.10"
 #define MagickppLibVersionNumber  8:0:0
-#define MagickppLibAddendum  "-34"
+#define MagickppLibAddendum  "-2"
 #define MagickppLibInterface  8
 #define MagickppLibMinInterface  8
-#define MagickReleaseDate  "2018-01-22"
+#define MagickReleaseDate  "2018-06-18"
 #define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6/index.html"
 #define MagickAuthoritativeLicense  \
-  "http://www.imagemagick.org/script/license.php"
-#define MagickAuthoritativeURL  "http://www.imagemagick.org"
+  "https://www.imagemagick.org/script/license.php"
+#define MagickAuthoritativeURL  "https://www.imagemagick.org"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
